<?php
/*
 * beroNet VoIP Gateway API
 *
 * Copyright (C) 2016 beroNet GmbH
 * Developer: Florian Kraatz <fk@beronet.com>
 *
 * If you experience problems with this component, please contact our support-team <support@beronet.com>
 */

// this is needed to check if api has been disabled
require_once('/usr/fallback/beroConf.php');

// generic table-display-function
function apiDisplayTable ($tableHead, $tableRows, $headSpan = null, $displayBack = null) {

	$table  =	'<table class="contenttoc" style="margin-top: 20px; margin-bottom: 20px; width: 50% !important;">' . "\n" .
			'<tr><th' . (($headSpan != null) ? ' colspan="' . $headSpan . '"': '') . '>' . $tableHead . '</th></tr>' . "\n" .
			$tableRows .
			(($displayBack != null) ? '<tr><td><input type="button" name="backButton" value="Overview" onclick="location.href=\'/app/api/api.php\'" /></td></tr>' . "\n" : '') .
			'</table>' . "\n";

	return($table);
}

// display overview of api-calls
function apiCallOverview () {

	$tableHeadline = 'Available Commands';
	$apiFunctions = scandir('/usr/local/php/api/');

	// remove virtual directories
	foreach (array('.', '..') as $virtDirectory) {
		if (($index = array_search($virtDirectory, $apiFunctions)) !== false) {
			unset($apiFunctions[$index]);
		}
	}

	if (empty($apiFunctions)) {
		return(apiDisplayTable($tableHeadline, '<tr><td>No API-Commands available!</td></tr>' . "\n"));
	}

	foreach ($apiFunctions as $apiFunction) {
		if (file_exists('/usr/local/php/api/' . $apiFunction . '/DISABLED')) {
			continue;
		}

		$apiInfo = file_get_contents('/usr/local/php/api/' . $apiFunction . '/info.txt');
		$tableRows .=	'<tr style="height: 45px;">' . "\n" .
				'<td style="width: 35%;">' .
				'<a href="?apiCommand=displayInfo&apiCall=' . $apiFunction . '"><b>' . $apiFunction . '</b></a>' .
				'</td>' . "\n" .
				'<td style="text-align:left !important;">' . $apiInfo . '</td>' . "\n" .
				'</tr>' . "\n";
	}

	return(apiDisplayTable($tableHeadline, $tableRows, 2));
}

// display description and example of an api-call
function apiCallInfo ($apiCallName) {

	$basePath = '/usr/local/php/api/' . $apiCallName;

	if (!isset($apiCallName) || (empty($apiCallName)) || !file_exists($basePath . '/description.txt') || file_exists($basePath . '/DISABLED')) {
		return(apiDisplayTable($apiCallName, '<tr><td>This API-call does not exist or is disabled.</td></tr>' . "\n", null, true));
	}

	$lines = file('/usr/local/php/api/' . $apiCallName . '/description.txt');
	foreach($lines as $line) {
		$tmp = explode("=>", $line);
		$description[$tmp[0]] = trim($tmp[1]);
		unset($tmp);
	}

	$apiUrl = 'http://' . $_SERVER['HTTP_HOST'] . '/app/api/api.php?apiCommand=' . $apiCallName;

	$tableRows =	'<tr><td style="text-align: left;">' . $description['helptext'] . '</td></tr>' . "\n" .
			'<tr><td style="text-align: left;">Usage' . "\n" .
			'<ul style="padding: 5px 15px;">' . "\n";
	foreach (explode(',', $description['usage']) as $value) {
			$tableRows .= '<li style="margin-left: 10px;">' . $value . '</li>' . "\n";
	}
	$tableRows .=	'</ul>' . "\n" .
			'</td></tr>' . "\n" .
			'<tr><td style="text-align: left;">Examples' . "\n" .
			'<ul style="padding: 5px 15px;">' . "\n";
	foreach (explode(',', $description['example']) as $value) {
		$tableRows .= '<li style="margin-left: 10px;"><a href="' . $apiUrl . $value . '">' . $apiUrl . $value . '</a></li>' . "\n";
	}
	$tableRows .=	'</ul>' . "\n" .
			'</td></tr>' . "\n" .
			'<tr><td style="text-align: left;">Return Values' . "\n" .
			'<ul style="padding: 5px 15px;">' . "\n";
	foreach (explode(',', $description['return']) as $value) {
		$tableRows .= '<li style="margin-left: 10px;">' . $apiCallName . ':' . $value . '</li>' . "\n";
	}
	$tableRows .=	'</ul>' . "\n" .
			'</td></tr>' . "\n";

	return(apiDisplayTable($apiCallName, $tableRows, null, true));
}

// if api is disabled, return 403
$bc = new beroConf('root');
if ($bc->get('root', 'api_disable') == '1') {
	header($_SERVER['SERVER_PROTOCOL'] . ' 403 Forbidden');
	exit(0);
}
unset($bc);

$apiCommand = isset($_POST['apiCommand']) ? $_POST['apiCommand'] : (isset($_GET['apiCommand']) ? $_GET['apiCommand'] : 'displayOverview');

// display info or overview
switch ($apiCommand) {
default:
	// run apiCommand and display result
	if (file_exists('/usr/local/php/api/' . $apiCommand . '/apiCall.class.php')) {
		if (file_exists('/usr/local/php/api/' . $cmd . '/DISABLED')) {
			echo $cmd . ':disabled';
			exit(1);
		}
		require_once('/usr/local/php/api/' . $apiCommand . '/apiCall.class.php');
		$api = new apiCall($_GET, $_POST, $_FILES);
		$api->execute();
		echo $api->display();
		exit(0);
	}
case 'displayOverview':
	$head = 'Overview';
	$table = apiCallOverview();
	break;
case 'displayInfo':
	$head = $_GET['apiCall'];
	$table = apiCallInfo($_GET['apiCall']);
	break;
}

// display html
echo	'<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1 Transitional//EN" ' . "\n" .
	'	"http://www.w3.org/TR/xhtml11/DTD/xhtml11-transitional.dtd">' . "\n" .
	'<html xmlns="http://www.w3.org/1999/xhtml">' ."\n" .
	'<head>' . "\n" .
	'<link rel="stylesheet" type="text/css" href="/app/berogui/includes/template_css.css" />' . "\n" .
	'<link rel="icon" href="/app/berogui/includes/images/favicon.ico" type="image/x-icon">' . "\n" .
	'<title>beroNet VoIP Gatway API: ' . $head . '</title>' . "\n" .
	'</head>' . "\n" .
	'<body>' . "\n" .
	'<div class="container" id="page">' . "\n" .
	'<div id="header" style="padding-bottom: 15px;">' . "\n" .
	'<div id="logo"><a href="http://www.beronet.com/" target="_blank" onfocus="if (this.blur()) { this.blur(); }">' .
	'<img src="/app/berogui/includes/images/beroNet.jpg" alt="beroNet" class="png" /></a></div>' . "\n" .
	'<div style="font-size: 18pt; color: #918e8c;">beroNet VoIP Gateway API</div>' . "\n" .
	'</div>' . "\n" .
	$table .
	'<div id="footer" class="clear">' . "\n" .
	'<div class="part1">Copyright &copy; 2016 beroNet GmbH, Germany</div>' . "\n" .
	'</div>' . "\n" .
	'</body>' . "\n" .
	'</html>';

?>
